@@ -15,7 +15,7 @@ package Doit::User;
 
 use strict;
 use warnings;
-our $VERSION = '0.032';
+our $VERSION = '0.03';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(as_user);
@@ -30,6 +30,10 @@ use Doit::Log;
 	my $cache = exists $opts{cache} ? delete $opts{cache} : 1;
 	error "Unhandled options: " . join(" ", %opts) if %opts;
 
+	if ($> != 0) {
+	    error "as_user works only for root";
+	}
+
 	my($uid, $gid, $homedir);
 	if ($cache) {
 	    ($uid, $gid, $homedir) = ($uid_cache{$user}, $gid_cache{$user}, $homedir_cache{$user});
@@ -47,11 +51,10 @@ use Doit::Log;
 	    }
 	}
 
-	# change first the gid, then the uid!
-	local $( = $gid; { my $errno = $!; if ($( != $gid) { error "Can't set real group id (wanted: $gid, is: $(): $errno" } }
-	local $) = $gid; { my $errno = $!; if ($) != $gid) { error "Can't set effective group id (wanted: $gid, is: $)): $errno" } }
-	local $< = $uid; { my $errno = $!; if ($< != $uid) { error "Can't set real user id (wanted: $uid, is: $<) : $errno" } }
-	local $> = $uid; { my $errno = $!; if ($> != $uid) { error "Can't set effective user id (wanted: $uid, is: $>): $errno" } }
+	local $( = $gid; # change first the gid, then the uid!
+	local $) = $gid;
+	local $< = $uid;
+	local $> = $uid;
 	local $ENV{HOME} = $homedir;
 	local $ENV{USER} = $user;
 	local $ENV{LOGNAME} = $user;
@@ -207,19 +210,15 @@ sub user_add_user_to_group {
     my $group = delete $opts{group};
     if (!defined $group) { error "group is mandatory" }
     my %user_groups = map{($_,1)} _get_user_groups($username);
-    my $changes = 0;
     if (!$user_groups{$group}) {
 	if      ($^O eq 'linux') {
 	    $self->system('usermod', '--append', '--groups', $group, $username);
-	    $changes = 1;
 	} elsif ($^O eq 'freebsd') {
 	    $self->system('pw', 'groupmod', '-m', $username, '-n', $group);
-	    $changes = 1;
 	} else {
 	    error "user_add_user_to_group NYI for $^O";
 	}
     }
-    $changes;
 }
 
 sub _get_user_groups {
@@ -233,7 +232,6 @@ sub _get_user_groups {
 	    push @groups, $gname;
 	}
     }
-    endgrent;
     @groups;
 }
 
